#' r from Multiple Regression
#'
#'The correation between the variable of interest (X) and the dependent variable (y), correlation between the control variable (z) and the dependent variable (Y) and the correlation between the variable of interest (x) and control variable (z) was used to estimate the standardized regression coefficients (B1).The B1 is the calculated effect size presented in r and in Fisher's transformed r.
#'@param  ry1     Correlation between the variable of interest (x) and dependent variable (Y)
#'@param  ry2     Correlation between the control variable and dependent variable (Y)
#'@param  r12     Correlation between variable of interest (x) and control variable (z)
#'@param  p       Number of predictors of Y (including X and all zs)
#'@param  N       Total sample size
#'@return Effect size  (ESr)
#'@return Fisher's transformed effect size r  (ESzr)
#'@return Variance for the Fisher's transformed r (Var)
#'@examples
#'ESr_multreg (0.7, 0.8, 0.5, 2, 50)
#'@export
ESr_multreg <-function (ry1, ry2, r12, p, N)
{
  ESr <- (ry1-(ry2*r12))/(1-(r12^2))
  ESzr <-.50*(log((1+ESr)/(1-ESr)))
  SEzr <-1/(sqrt(N-p-2))  
  VARzr <-SEzr^2
  return (setNames((list(ESr, ESzr, VARzr)),c("Effect Size", "Fisher's transformed r", "Variance")))
}

